svn commit: samba r5833 - in branches/SAMBA_3_0/source/smbd: .

jra at samba.org jra at samba.org
Wed Mar 16 19:31:15 GMT 2005


Author: jra
Date: 2005-03-16 19:31:15 +0000 (Wed, 16 Mar 2005)
New Revision: 5833

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=5833

Log:
Revert change for bug #2335. Tested with a Win9x client and the original
error code is correct. I have some theories as to why this is different,
I'll add some code to the torture tester to confirm.
Jeremy.

Modified:
   branches/SAMBA_3_0/source/smbd/trans2.c


Changeset:
Modified: branches/SAMBA_3_0/source/smbd/trans2.c
===================================================================
--- branches/SAMBA_3_0/source/smbd/trans2.c	2005-03-16 18:22:32 UTC (rev 5832)
+++ branches/SAMBA_3_0/source/smbd/trans2.c	2005-03-16 19:31:15 UTC (rev 5833)
@@ -1484,13 +1484,13 @@
 	}
 
 	/* 
 	 * If there are no matching entries we must return ERRDOS/ERRnofiles - 
 	 * from observation of NT.
 	 */
 
 	if(numentries == 0) {
 		dptr_close(&dptr_num);
-		return ERROR_DOS(ERRDOS,ERRnofiles);
+		return ERROR_DOS(ERRDOS,ERRbadfile);
 	}
 
 	/* At this point pdata points to numentries directory entries. */
@@ -1484,13 +1484,13 @@
 
 	/* 
-	 * If there are no matching entries we must return ERRDOS/ERRnofiles - 
+	 * If there are no matching entries we must return ERRDOS/ERRbadfile - 
 	 * from observation of NT.
 	 */



More information about the samba-cvs mailing list